# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from robotnikai.models.api_key_distribution_enum import ApiKeyDistributionEnum
from robotnikai.models.hmac_algorithm_enum import HmacAlgorithmEnum
from robotnikai.models.integration_settings_hmac_key_format import IntegrationSettingsHmacKeyFormat
from robotnikai.models.integration_type import IntegrationType
from typing import Optional, Set
from typing_extensions import Self

class IntegrationSettings(BaseModel):
    """
    IntegrationSettings
    """ # noqa: E501
    integration_id: Annotated[str, Field(strict=True, max_length=100)]
    type: Optional[IntegrationType] = None
    connected_accounts: Optional[Any] = None
    account_fields: Optional[Any] = Field(default=None, description="Pola identyfikujące użytkownika")
    dependencies: Optional[Any] = Field(default=None, description="Zależności wymagane do działania integracji")
    scope: Optional[StrictStr] = None
    accept_header: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    api_auth_header_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    api_auth_header_key: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    api_key_distribution: Optional[ApiKeyDistributionEnum] = None
    api_key_query_param_key: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    api_key_body_param_key: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    api_base_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    api_schema: Optional[Any] = None
    authorize_url: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    access_token_url: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    identity_url: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    oauth_basic_auth: Optional[StrictBool] = None
    oauth_pkce_enabled: Optional[StrictBool] = None
    variables: Optional[Any] = None
    openapi_json_scheme_url: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    is_sandbox: Optional[StrictBool] = None
    hmac_algorithm: Optional[HmacAlgorithmEnum] = None
    hmac_fields: Optional[Any] = Field(default=None, description="Fields to include in HMAC signature")
    hmac_separator: Optional[Annotated[str, Field(strict=True, max_length=20)]] = None
    hmac_header_placeholder: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    hmac_custom_signature_field: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    hmac_key_format: Optional[IntegrationSettingsHmacKeyFormat] = None
    status_check_url: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    __properties: ClassVar[List[str]] = ["integration_id", "type", "connected_accounts", "account_fields", "dependencies", "scope", "accept_header", "api_auth_header_name", "api_auth_header_key", "api_key_distribution", "api_key_query_param_key", "api_key_body_param_key", "api_base_url", "api_schema", "authorize_url", "access_token_url", "identity_url", "oauth_basic_auth", "oauth_pkce_enabled", "variables", "openapi_json_scheme_url", "is_sandbox", "hmac_algorithm", "hmac_fields", "hmac_separator", "hmac_header_placeholder", "hmac_custom_signature_field", "hmac_key_format", "status_check_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IntegrationSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "type",
            "connected_accounts",
            "variables",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of type
        if self.type:
            _dict['type'] = self.type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hmac_key_format
        if self.hmac_key_format:
            _dict['hmac_key_format'] = self.hmac_key_format.to_dict()
        # set to None if connected_accounts (nullable) is None
        # and model_fields_set contains the field
        if self.connected_accounts is None and "connected_accounts" in self.model_fields_set:
            _dict['connected_accounts'] = None

        # set to None if account_fields (nullable) is None
        # and model_fields_set contains the field
        if self.account_fields is None and "account_fields" in self.model_fields_set:
            _dict['account_fields'] = None

        # set to None if dependencies (nullable) is None
        # and model_fields_set contains the field
        if self.dependencies is None and "dependencies" in self.model_fields_set:
            _dict['dependencies'] = None

        # set to None if accept_header (nullable) is None
        # and model_fields_set contains the field
        if self.accept_header is None and "accept_header" in self.model_fields_set:
            _dict['accept_header'] = None

        # set to None if api_schema (nullable) is None
        # and model_fields_set contains the field
        if self.api_schema is None and "api_schema" in self.model_fields_set:
            _dict['api_schema'] = None

        # set to None if authorize_url (nullable) is None
        # and model_fields_set contains the field
        if self.authorize_url is None and "authorize_url" in self.model_fields_set:
            _dict['authorize_url'] = None

        # set to None if access_token_url (nullable) is None
        # and model_fields_set contains the field
        if self.access_token_url is None and "access_token_url" in self.model_fields_set:
            _dict['access_token_url'] = None

        # set to None if identity_url (nullable) is None
        # and model_fields_set contains the field
        if self.identity_url is None and "identity_url" in self.model_fields_set:
            _dict['identity_url'] = None

        # set to None if variables (nullable) is None
        # and model_fields_set contains the field
        if self.variables is None and "variables" in self.model_fields_set:
            _dict['variables'] = None

        # set to None if hmac_fields (nullable) is None
        # and model_fields_set contains the field
        if self.hmac_fields is None and "hmac_fields" in self.model_fields_set:
            _dict['hmac_fields'] = None

        # set to None if hmac_separator (nullable) is None
        # and model_fields_set contains the field
        if self.hmac_separator is None and "hmac_separator" in self.model_fields_set:
            _dict['hmac_separator'] = None

        # set to None if hmac_key_format (nullable) is None
        # and model_fields_set contains the field
        if self.hmac_key_format is None and "hmac_key_format" in self.model_fields_set:
            _dict['hmac_key_format'] = None

        # set to None if status_check_url (nullable) is None
        # and model_fields_set contains the field
        if self.status_check_url is None and "status_check_url" in self.model_fields_set:
            _dict['status_check_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IntegrationSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "integration_id": obj.get("integration_id"),
            "type": IntegrationType.from_dict(obj["type"]) if obj.get("type") is not None else None,
            "connected_accounts": obj.get("connected_accounts"),
            "account_fields": obj.get("account_fields"),
            "dependencies": obj.get("dependencies"),
            "scope": obj.get("scope"),
            "accept_header": obj.get("accept_header"),
            "api_auth_header_name": obj.get("api_auth_header_name"),
            "api_auth_header_key": obj.get("api_auth_header_key"),
            "api_key_distribution": obj.get("api_key_distribution"),
            "api_key_query_param_key": obj.get("api_key_query_param_key"),
            "api_key_body_param_key": obj.get("api_key_body_param_key"),
            "api_base_url": obj.get("api_base_url"),
            "api_schema": obj.get("api_schema"),
            "authorize_url": obj.get("authorize_url"),
            "access_token_url": obj.get("access_token_url"),
            "identity_url": obj.get("identity_url"),
            "oauth_basic_auth": obj.get("oauth_basic_auth"),
            "oauth_pkce_enabled": obj.get("oauth_pkce_enabled"),
            "variables": obj.get("variables"),
            "openapi_json_scheme_url": obj.get("openapi_json_scheme_url"),
            "is_sandbox": obj.get("is_sandbox"),
            "hmac_algorithm": obj.get("hmac_algorithm"),
            "hmac_fields": obj.get("hmac_fields"),
            "hmac_separator": obj.get("hmac_separator"),
            "hmac_header_placeholder": obj.get("hmac_header_placeholder"),
            "hmac_custom_signature_field": obj.get("hmac_custom_signature_field"),
            "hmac_key_format": IntegrationSettingsHmacKeyFormat.from_dict(obj["hmac_key_format"]) if obj.get("hmac_key_format") is not None else None,
            "status_check_url": obj.get("status_check_url")
        })
        return _obj





# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MongoMigrationStatusEnum(str, Enum):
    """
    * `pending` - Pending * `in_progress` - In Progress * `completed` - Completed * `failed` - Failed * `canceled` - Canceled
    """

    """
    allowed enum values
    """
    PENDING = 'pending'
    IN_PROGRESS = 'in_progress'
    COMPLETED = 'completed'
    FAILED = 'failed'
    CANCELED = 'canceled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MongoMigrationStatusEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_tags_api import ApplicationsTablesTagsApi


class TestApplicationsTablesTagsApi(unittest.TestCase):
    """ApplicationsTablesTagsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesTagsApi()

    def tearDown(self) -> None:
        pass

    def test_apps_table_tags_retrieve(self) -> None:
        """Test case for apps_table_tags_retrieve

        Get Table Tags
        """
        pass

    def test_apps_table_tags_tag_destroy(self) -> None:
        """Test case for apps_table_tags_tag_destroy

        Get Tag by ID
        """
        pass

    def test_apps_table_tags_tag_retrieve(self) -> None:
        """Test case for apps_table_tags_tag_retrieve

        Get Tag by ID
        """
        pass

    def test_apps_table_tags_tag_update(self) -> None:
        """Test case for apps_table_tags_tag_update

        Get Tag by ID
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.csv_export_request import CsvExportRequest

class TestCsvExportRequest(unittest.TestCase):
    """CsvExportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CsvExportRequest:
        """Test CsvExportRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CsvExportRequest`
        """
        model = CsvExportRequest()
        if include_optional:
            return CsvExportRequest(
                collection_name = '0',
                file = bytes(b'blah'),
                task_id = '',
                application = 56,
                user = 56
            )
        else:
            return CsvExportRequest(
                collection_name = '0',
                application = 56,
                user = 56,
        )
        """

    def testCsvExportRequest(self):
        """Test CsvExportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from robotnikai.models.integration_type import IntegrationType
from typing import Optional, Set
from typing_extensions import Self

class PatchedIntegration(BaseModel):
    """
    PatchedIntegration
    """ # noqa: E501
    integration_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = None
    type: Optional[IntegrationType] = None
    name: Optional[Annotated[str, Field(strict=True, max_length=150)]] = None
    tags: Optional[List[StrictStr]] = None
    version: Optional[Annotated[str, Field(strict=True, max_length=10)]] = None
    icon: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    account_fields: Optional[Any] = Field(default=None, description="Pola identyfikujące użytkownika")
    dependencies: Optional[Any] = Field(default=None, description="Zależności wymagane do działania integracji")
    configuration_form: Optional[Any] = None
    activated: Optional[StrictBool] = None
    owner: Optional[StrictStr] = None
    connected_accounts: Optional[StrictInt] = None
    client_id: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    secret: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    access_token_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    authorize_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    identity_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    scope: Optional[StrictStr] = None
    basic_auth: Optional[StrictBool] = False
    accept_header: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    fetch_userinfo: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    api_key: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    api_auth_header_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = 'Bearer'
    api_base_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    __properties: ClassVar[List[str]] = ["integration_id", "type", "name", "tags", "version", "icon", "description", "account_fields", "dependencies", "configuration_form", "activated", "owner", "connected_accounts", "client_id", "secret", "access_token_url", "authorize_url", "identity_url", "scope", "basic_auth", "accept_header", "fetch_userinfo", "api_key", "api_auth_header_name", "api_base_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedIntegration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "type",
            "activated",
            "owner",
            "connected_accounts",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of type
        if self.type:
            _dict['type'] = self.type.to_dict()
        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if account_fields (nullable) is None
        # and model_fields_set contains the field
        if self.account_fields is None and "account_fields" in self.model_fields_set:
            _dict['account_fields'] = None

        # set to None if dependencies (nullable) is None
        # and model_fields_set contains the field
        if self.dependencies is None and "dependencies" in self.model_fields_set:
            _dict['dependencies'] = None

        # set to None if configuration_form (nullable) is None
        # and model_fields_set contains the field
        if self.configuration_form is None and "configuration_form" in self.model_fields_set:
            _dict['configuration_form'] = None

        # set to None if connected_accounts (nullable) is None
        # and model_fields_set contains the field
        if self.connected_accounts is None and "connected_accounts" in self.model_fields_set:
            _dict['connected_accounts'] = None

        # set to None if client_id (nullable) is None
        # and model_fields_set contains the field
        if self.client_id is None and "client_id" in self.model_fields_set:
            _dict['client_id'] = None

        # set to None if secret (nullable) is None
        # and model_fields_set contains the field
        if self.secret is None and "secret" in self.model_fields_set:
            _dict['secret'] = None

        # set to None if access_token_url (nullable) is None
        # and model_fields_set contains the field
        if self.access_token_url is None and "access_token_url" in self.model_fields_set:
            _dict['access_token_url'] = None

        # set to None if authorize_url (nullable) is None
        # and model_fields_set contains the field
        if self.authorize_url is None and "authorize_url" in self.model_fields_set:
            _dict['authorize_url'] = None

        # set to None if identity_url (nullable) is None
        # and model_fields_set contains the field
        if self.identity_url is None and "identity_url" in self.model_fields_set:
            _dict['identity_url'] = None

        # set to None if basic_auth (nullable) is None
        # and model_fields_set contains the field
        if self.basic_auth is None and "basic_auth" in self.model_fields_set:
            _dict['basic_auth'] = None

        # set to None if accept_header (nullable) is None
        # and model_fields_set contains the field
        if self.accept_header is None and "accept_header" in self.model_fields_set:
            _dict['accept_header'] = None

        # set to None if fetch_userinfo (nullable) is None
        # and model_fields_set contains the field
        if self.fetch_userinfo is None and "fetch_userinfo" in self.model_fields_set:
            _dict['fetch_userinfo'] = None

        # set to None if api_key (nullable) is None
        # and model_fields_set contains the field
        if self.api_key is None and "api_key" in self.model_fields_set:
            _dict['api_key'] = None

        # set to None if api_auth_header_name (nullable) is None
        # and model_fields_set contains the field
        if self.api_auth_header_name is None and "api_auth_header_name" in self.model_fields_set:
            _dict['api_auth_header_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedIntegration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "integration_id": obj.get("integration_id"),
            "type": IntegrationType.from_dict(obj["type"]) if obj.get("type") is not None else None,
            "name": obj.get("name"),
            "tags": obj.get("tags"),
            "version": obj.get("version"),
            "icon": obj.get("icon"),
            "description": obj.get("description"),
            "account_fields": obj.get("account_fields"),
            "dependencies": obj.get("dependencies"),
            "configuration_form": obj.get("configuration_form"),
            "activated": obj.get("activated"),
            "owner": obj.get("owner"),
            "connected_accounts": obj.get("connected_accounts"),
            "client_id": obj.get("client_id"),
            "secret": obj.get("secret"),
            "access_token_url": obj.get("access_token_url"),
            "authorize_url": obj.get("authorize_url"),
            "identity_url": obj.get("identity_url"),
            "scope": obj.get("scope"),
            "basic_auth": obj.get("basic_auth") if obj.get("basic_auth") is not None else False,
            "accept_header": obj.get("accept_header"),
            "fetch_userinfo": obj.get("fetch_userinfo"),
            "api_key": obj.get("api_key"),
            "api_auth_header_name": obj.get("api_auth_header_name") if obj.get("api_auth_header_name") is not None else 'Bearer',
            "api_base_url": obj.get("api_base_url")
        })
        return _obj





# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_csv_import_api import ApplicationsTablesCSVImportApi


class TestApplicationsTablesCSVImportApi(unittest.TestCase):
    """ApplicationsTablesCSVImportApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesCSVImportApi()

    def tearDown(self) -> None:
        pass

    def test_apps_csv_imports_create(self) -> None:
        """Test case for apps_csv_imports_create

        """
        pass

    def test_apps_csv_imports_destroy(self) -> None:
        """Test case for apps_csv_imports_destroy

        """
        pass

    def test_apps_csv_imports_list(self) -> None:
        """Test case for apps_csv_imports_list

        """
        pass

    def test_apps_csv_imports_partial_update(self) -> None:
        """Test case for apps_csv_imports_partial_update

        """
        pass

    def test_apps_csv_imports_retrieve(self) -> None:
        """Test case for apps_csv_imports_retrieve

        """
        pass

    def test_apps_csv_imports_update(self) -> None:
        """Test case for apps_csv_imports_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
CUA API

Documentation of API endpoints of CUA

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import os
import unittest
from pprint import pprint

import robotnikai
from dotenv import load_dotenv
from robotnikai.api.applications_api import ApplicationsApi
from robotnikai.rest import ApiException
from robotnikai.wrapper import API


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self) -> None:
        load_dotenv()

        # Create API client with configuration
        self.api = API()

        # Store test app ID for use across tests
        self.test_app_id = None
        self.test_app_name = "Test Application for API Tests"

    def tearDown(self) -> None:
        # Clean up any test application that was created
        if self.test_app_id:
            try:
                self.api.apps.delete_app(self.test_app_id)
                print(f"Cleaned up test application with ID: {self.test_app_id}")
                self.test_app_id = None
            except ApiException:
                print(
                    f"Warning: Could not delete test application with ID: {self.test_app_id}"
                )
                pass

    def test_apps_create(self) -> None:
        """Test case for apps_create

        Create Application
        """
        # try:
        # Create application object with test data
        application = robotnikai.Application(
            name=self.test_app_name,
        )

        # Call the create API
        api_response = self.api.apps.create_app(application)

        # Store the app ID for use in other tests
        self.test_app_id = api_response.id

        # Assertions to verify the response
        self.assertIsNotNone(api_response)
        self.assertEqual(api_response.name, self.test_app_name)
        self.assertIsNotNone(api_response.id)

        print("Test application created successfully:")
        pprint(api_response)

        # except ApiException as e:
        #     self.fail(f"Exception when calling ApplicationsApi->create_app: {e}")

        return api_response

    def test_apps_retrieve(self) -> None:
        """Test case for apps_retrieve

        Retrieve Application
        """
        # First create a test application if we don't have one
        if not self.test_app_id:
            app = self.test_apps_create()
            self.test_app_id = app.id

        try:
            # Retrieve the application by ID
            api_response = self.api.apps.get_app(self.test_app_id)

            # Verify the response
            self.assertIsNotNone(api_response)
            self.assertEqual(api_response.id, self.test_app_id)
            self.assertEqual(api_response.name, self.test_app_name)

            print("Test application retrieved successfully:")
            pprint(api_response)

        except ApiException as e:
            self.fail(f"Exception when calling ApplicationsApi->get_app: {e}")

    def test_apps_list(self) -> None:
        """Test case for apps_list

        List Applications
        """
        # First create a test application if we don't have one
        if not self.test_app_id:
            app = self.test_apps_create()
            self.test_app_id = app.id

        try:
            # Get list of applications
            api_response = self.api.apps.get_apps()

            # Verify the response
            self.assertIsNotNone(api_response)
            self.assertIsNotNone(api_response.results)
            self.assertIsInstance(api_response.results, list)

            print(
                f"Applications list retrieved successfully, found {len(api_response.results)} applications"
            )

        except ApiException as e:
            self.fail(f"Exception when calling ApplicationsApi->get_apps: {e}")

    def test_apps_update(self) -> None:
        """Test case for apps_update

        Update Application
        """
        # First create a test application if we don't have one
        if not self.test_app_id:
            app = self.test_apps_create()
            self.test_app_id = app.id

        try:
            # Create updated application object
            updated_name = f"{self.test_app_name} - Updated"
            application = robotnikai.Application(
                name=updated_name,
            )

            # Update the application
            api_response = self.api.apps.update_app(self.test_app_id, application)

            # Verify the response
            self.assertIsNotNone(api_response)
            self.assertEqual(api_response.id, self.test_app_id)
            self.assertEqual(api_response.name, updated_name)

            # Update test app name to match the updated value
            self.test_app_name = updated_name

            print("Test application updated successfully:")
            pprint(api_response)

        except ApiException as e:
            self.fail(f"Exception when calling ApplicationsApi->update_app: {e}")

    def test_apps_destroy(self) -> None:
        """Test case for apps_destroy

        Delete Application
        """
        # First create a test application if we don't have one
        if not self.test_app_id:
            app = self.test_apps_create()
            self.test_app_id = app.id

        try:
            # Delete the application
            self.api.apps.delete_app(self.test_app_id)

            # Verify deletion by trying to retrieve it (should raise ApiException)
            try:
                self.api.apps.get_app(self.test_app_id)
                self.fail("Application was not deleted successfully")
            except ApiException as e:
                # Expected 404 Not Found
                self.assertEqual(e.status, 404)

            print(f"Test application deleted successfully: {self.test_app_id}")

            # Clear the test app ID since it's been deleted
            self.test_app_id = None

        except ApiException as e:
            self.fail(f"Exception when calling ApplicationsApi->delete_app: {e}")


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_api import ApplicationsTablesApi


class TestApplicationsTablesApi(unittest.TestCase):
    """ApplicationsTablesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesApi()

    def tearDown(self) -> None:
        pass

    def test_apps_edit_table_update(self) -> None:
        """Test case for apps_edit_table_update

        Edit Application Table
        """
        pass

    def test_apps_get_app_retrieve(self) -> None:
        """Test case for apps_get_app_retrieve

        """
        pass

    def test_apps_new_table_create(self) -> None:
        """Test case for apps_new_table_create

        Create Application Table
        """
        pass

    def test_apps_table_configuration_update(self) -> None:
        """Test case for apps_table_configuration_update

        Get Application Table Configuration
        """
        pass

    def test_apps_table_delete_rows_destroy(self) -> None:
        """Test case for apps_table_delete_rows_destroy

        Delete Rows from Application Table
        """
        pass

    def test_apps_table_new_row_create(self) -> None:
        """Test case for apps_table_new_row_create

        Add Row to Application Table
        """
        pass

    def test_apps_table_rows_retrieve(self) -> None:
        """Test case for apps_table_rows_retrieve

        Get Row from Application Table
        """
        pass

    def test_apps_table_rows_update(self) -> None:
        """Test case for apps_table_rows_update

        Get Row from Application Table
        """
        pass

    def test_apps_tables_retrieve(self) -> None:
        """Test case for apps_tables_retrieve

        Get Application Tables
        """
        pass

    def test_apps_user_tables_retrieve(self) -> None:
        """Test case for apps_user_tables_retrieve

        Get User Application Tables
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.get_list200_response_inner import GetList200ResponseInner

class TestGetList200ResponseInner(unittest.TestCase):
    """GetList200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetList200ResponseInner:
        """Test GetList200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetList200ResponseInner`
        """
        model = GetList200ResponseInner()
        if include_optional:
            return GetList200ResponseInner(
                id = ''
            )
        else:
            return GetList200ResponseInner(
                id = '',
        )
        """

    def testGetList200ResponseInner(self):
        """Test GetList200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.plugin_interface import PluginInterface

class TestPluginInterface(unittest.TestCase):
    """PluginInterface unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PluginInterface:
        """Test PluginInterface
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PluginInterface`
        """
        model = PluginInterface()
        if include_optional:
            return PluginInterface(
                id = 56,
                organization = 56,
                app = 56,
                integrations = '',
                plugins = '',
                title = '',
                namespace = 'z',
                description = '',
                capabilities = [
                    ''
                    ],
                is_visible = True,
                json_schema = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                tables = [
                    56
                    ]
            )
        else:
            return PluginInterface(
                app = 56,
                title = '',
                namespace = 'z',
        )
        """

    def testPluginInterface(self):
        """Test PluginInterface"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.integration_settings import IntegrationSettings

class TestIntegrationSettings(unittest.TestCase):
    """IntegrationSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationSettings:
        """Test IntegrationSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationSettings`
        """
        model = IntegrationSettings()
        if include_optional:
            return IntegrationSettings(
                integration_id = '',
                type = robotnikai.models.integration_type.IntegrationType(
                    code = '', 
                    name = '', 
                    icon = '', ),
                connected_accounts = None,
                account_fields = None,
                dependencies = None,
                scope = '',
                accept_header = '',
                api_auth_header_name = '',
                api_auth_header_key = '',
                api_base_url = ''
            )
        else:
            return IntegrationSettings(
                integration_id = '',
        )
        """

    def testIntegrationSettings(self):
        """Test IntegrationSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from robotnikai.models.mongo_migration_status_enum import MongoMigrationStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class MongoMigrationRequest(BaseModel):
    """
    MongoMigrationRequest
    """ # noqa: E501
    status: Optional[MongoMigrationStatusEnum] = None
    collection_name: Annotated[str, Field(min_length=1, strict=True, max_length=150)]
    migration_name: Annotated[str, Field(min_length=1, strict=True, max_length=150)]
    old_schema: Optional[Any] = None
    new_schema: Optional[Any] = None
    renamed: Optional[Any] = None
    added: Optional[Any] = None
    removed: Optional[Any] = None
    changed: Optional[Any] = None
    task_id: Optional[Annotated[str, Field(strict=True, max_length=150)]] = None
    type_conversion_policy: Optional[Any] = None
    application: StrictInt
    __properties: ClassVar[List[str]] = ["status", "collection_name", "migration_name", "old_schema", "new_schema", "renamed", "added", "removed", "changed", "task_id", "type_conversion_policy", "application"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MongoMigrationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if old_schema (nullable) is None
        # and model_fields_set contains the field
        if self.old_schema is None and "old_schema" in self.model_fields_set:
            _dict['old_schema'] = None

        # set to None if new_schema (nullable) is None
        # and model_fields_set contains the field
        if self.new_schema is None and "new_schema" in self.model_fields_set:
            _dict['new_schema'] = None

        # set to None if renamed (nullable) is None
        # and model_fields_set contains the field
        if self.renamed is None and "renamed" in self.model_fields_set:
            _dict['renamed'] = None

        # set to None if added (nullable) is None
        # and model_fields_set contains the field
        if self.added is None and "added" in self.model_fields_set:
            _dict['added'] = None

        # set to None if removed (nullable) is None
        # and model_fields_set contains the field
        if self.removed is None and "removed" in self.model_fields_set:
            _dict['removed'] = None

        # set to None if changed (nullable) is None
        # and model_fields_set contains the field
        if self.changed is None and "changed" in self.model_fields_set:
            _dict['changed'] = None

        # set to None if task_id (nullable) is None
        # and model_fields_set contains the field
        if self.task_id is None and "task_id" in self.model_fields_set:
            _dict['task_id'] = None

        # set to None if type_conversion_policy (nullable) is None
        # and model_fields_set contains the field
        if self.type_conversion_policy is None and "type_conversion_policy" in self.model_fields_set:
            _dict['type_conversion_policy'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MongoMigrationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "status": obj.get("status"),
            "collection_name": obj.get("collection_name"),
            "migration_name": obj.get("migration_name"),
            "old_schema": obj.get("old_schema"),
            "new_schema": obj.get("new_schema"),
            "renamed": obj.get("renamed"),
            "added": obj.get("added"),
            "removed": obj.get("removed"),
            "changed": obj.get("changed"),
            "task_id": obj.get("task_id"),
            "type_conversion_policy": obj.get("type_conversion_policy"),
            "application": obj.get("application")
        })
        return _obj





# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Application(BaseModel):
    """
    Application
    """ # noqa: E501
    id: Optional[StrictInt] = None
    organization: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    activated: Optional[StrictBool] = None
    icon: Optional[StrictStr] = None
    configuration_schema_available: Optional[StrictBool] = None
    authorized: Optional[StrictBool] = None
    is_official: Optional[StrictBool] = None
    is_active: Optional[StrictBool] = None
    name: Annotated[str, Field(strict=True, max_length=150)]
    slug: Optional[Annotated[str, Field(strict=True)]] = None
    description: Optional[StrictStr] = None
    is_public: Optional[StrictBool] = None
    is_open_source: Optional[StrictBool] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    forked_from: Optional[StrictInt] = Field(default=None, description="If this application is a fork, this field points to the original application.")
    __properties: ClassVar[List[str]] = ["id", "organization", "url", "activated", "icon", "configuration_schema_available", "authorized", "is_official", "is_active", "name", "slug", "description", "is_public", "is_open_source", "created_at", "updated_at", "forked_from"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Application from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "organization",
            "url",
            "activated",
            "configuration_schema_available",
            "authorized",
            "is_official",
            "slug",
            "created_at",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if organization (nullable) is None
        # and model_fields_set contains the field
        if self.organization is None and "organization" in self.model_fields_set:
            _dict['organization'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if activated (nullable) is None
        # and model_fields_set contains the field
        if self.activated is None and "activated" in self.model_fields_set:
            _dict['activated'] = None

        # set to None if icon (nullable) is None
        # and model_fields_set contains the field
        if self.icon is None and "icon" in self.model_fields_set:
            _dict['icon'] = None

        # set to None if configuration_schema_available (nullable) is None
        # and model_fields_set contains the field
        if self.configuration_schema_available is None and "configuration_schema_available" in self.model_fields_set:
            _dict['configuration_schema_available'] = None

        # set to None if authorized (nullable) is None
        # and model_fields_set contains the field
        if self.authorized is None and "authorized" in self.model_fields_set:
            _dict['authorized'] = None

        # set to None if forked_from (nullable) is None
        # and model_fields_set contains the field
        if self.forked_from is None and "forked_from" in self.model_fields_set:
            _dict['forked_from'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Application from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "organization": obj.get("organization"),
            "url": obj.get("url"),
            "activated": obj.get("activated"),
            "icon": obj.get("icon"),
            "configuration_schema_available": obj.get("configuration_schema_available"),
            "authorized": obj.get("authorized"),
            "is_official": obj.get("is_official"),
            "is_active": obj.get("is_active"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "description": obj.get("description"),
            "is_public": obj.get("is_public"),
            "is_open_source": obj.get("is_open_source"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "forked_from": obj.get("forked_from")
        })
        return _obj





# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.mongo_migration import MongoMigration

class TestMongoMigration(unittest.TestCase):
    """MongoMigration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MongoMigration:
        """Test MongoMigration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MongoMigration`
        """
        model = MongoMigration()
        if include_optional:
            return MongoMigration(
                id = 56,
                status = 'pending',
                collection_name = '',
                migration_name = '',
                old_schema = None,
                new_schema = None,
                renamed = None,
                added = None,
                removed = None,
                changed = None,
                task_id = '',
                type_conversion_policy = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                application = 56
            )
        else:
            return MongoMigration(
                id = 56,
                collection_name = '',
                migration_name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                application = 56,
        )
        """

    def testMongoMigration(self):
        """Test MongoMigration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
CUA API

Documentation of API endpoints of CUA

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import datetime
import unittest


from robotnikai.models.application import Application


class TestApplication(unittest.TestCase):
    """Application unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self,
    ) -> Application:
        """Test Application
        This method creates an instance of the Application model with minimal required attributes to test its functionality and validation.
        """

        return Application(
            id=56,
            creator="",
            url="",
            activated=True,
            name="Test application",
            slug="z",
            created_at=datetime.datetime.strptime(
                "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
            ),
            updated_at=datetime.datetime.strptime(
                "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
            ),
        )

    def testApplication(self):
        """Test Application"""
        inst_req_only = self.make_instance()
        self.assertTrue(isinstance(inst_req_only, Application), "Should be an instance of Application")
        self.assertTrue(inst_req_only.id == 56, "id should be 56")
        self.assertTrue(inst_req_only.creator == "", "creator should be an empty string")
        self.assertTrue(inst_req_only.url == "", "url should be an empty string")
        self.assertTrue(inst_req_only.activated is True, "activated should be True")
        self.assertEqual(
            inst_req_only.name, "Test application", "name should be 'Test application'"
        )
        


if __name__ == "__main__":
    unittest.main()
